@@ -321,7 +321,7 @@ hd_desktop_select_plugins (HildonDesktopWindow *window, gpointer user_data)
   loaded_plugins = gtk_container_get_children (window->container);
 
   response = hd_select_plugins_dialog_run (loaded_plugins,
-#ifdef HAVE_LIBOSSOHELP
+#ifdef HAVE_LIBHILDONHELP
                                            priv->osso_context,
 #endif 
                                            info->plugin_dir,
@@ -806,6 +806,7 @@ hd_desktop_load_containers (HDDesktop *desktop)
                                         "width", width,
                                         "height", height,
                                         "orientation", orientation,
+                                        "stretch", TRUE,
                                          NULL);
       }
       else if (!g_ascii_strcasecmp (type, HD_CONTAINER_TYPE_PANEL_EXPANDABLE))
